Class: Mindee::V1::Product::FR::BankAccountDetails::BankAccountDetailsV1Document
- Inherits:
-
Mindee::V1::Parsing::Common::Prediction
- Object
- Mindee::V1::Parsing::Common::Prediction
- Mindee::V1::Product::FR::BankAccountDetails::BankAccountDetailsV1Document
- Includes:
- Mindee::V1::Parsing::Standard
- Defined in:
- lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb
Overview
Bank Account Details API version 1.0 document data.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Mindee::V1::Parsing::Standard::StringField
readonly
The name of the account holder as seen on the document.
-
#iban ⇒ Mindee::V1::Parsing::Standard::StringField
readonly
The International Bank Account Number (IBAN).
-
#swift ⇒ Mindee::V1::Parsing::Standard::StringField
readonly
The bank's SWIFT Business Identifier Code (BIC).
Instance Method Summary collapse
-
#initialize(prediction, page_id) ⇒ BankAccountDetailsV1Document
constructor
A new instance of BankAccountDetailsV1Document.
- #to_s ⇒ String
Constructor Details
#initialize(prediction, page_id) ⇒ BankAccountDetailsV1Document
Returns a new instance of BankAccountDetailsV1Document.
26 27 28 29 30 31 32 33 34 |
# File 'lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb', line 26 def initialize(prediction, page_id) super @account_holder_name = Parsing::Standard::StringField.new( prediction['account_holder_name'], page_id ) @iban = Parsing::Standard::StringField.new(prediction['iban'], page_id) @swift = Parsing::Standard::StringField.new(prediction['swift'], page_id) end |
Instance Attribute Details
#account_holder_name ⇒ Mindee::V1::Parsing::Standard::StringField (readonly)
The name of the account holder as seen on the document.
16 17 18 |
# File 'lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb', line 16 def account_holder_name @account_holder_name end |
#iban ⇒ Mindee::V1::Parsing::Standard::StringField (readonly)
The International Bank Account Number (IBAN).
19 20 21 |
# File 'lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb', line 19 def iban @iban end |
#swift ⇒ Mindee::V1::Parsing::Standard::StringField (readonly)
The bank's SWIFT Business Identifier Code (BIC).
22 23 24 |
# File 'lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb', line 22 def swift @swift end |
Instance Method Details
#to_s ⇒ String
37 38 39 40 41 42 43 |
# File 'lib/mindee/v1/product/fr/bank_account_details/bank_account_details_v1_document.rb', line 37 def to_s out_str = String.new out_str << "\n:IBAN: #{@iban}".rstrip out_str << "\n:Account Holder's Name: #{@account_holder_name}".rstrip out_str << "\n:SWIFT Code: #{@swift}".rstrip out_str[1..].to_s end |