Module: MiniMagick

Defined in:
sig/custom/mini_magick.rbs

Overview

Stub for the mini_magick library. NOTE: though typing annotations for the MiniMagick library now exist, it seems that they aren't strict enough to match the rules we have on the repo, hence the existence of this file and the overrides present below.

Defined Under Namespace

Classes: Image