Class: Mindee::V2::Product::Classification::ClassificationClassifier
- Inherits:
-
Object
- Object
- Mindee::V2::Product::Classification::ClassificationClassifier
- Defined in:
- lib/mindee/v2/product/classification/classification_classifier.rb
Overview
Classification of document type from the source file.
Instance Attribute Summary collapse
-
#document_type ⇒ String
readonly
The document type, as identified on given classification values.
Instance Method Summary collapse
-
#initialize(server_response) ⇒ ClassificationClassifier
constructor
A new instance of ClassificationClassifier.
-
#to_s ⇒ String
String representation.
Constructor Details
#initialize(server_response) ⇒ ClassificationClassifier
Returns a new instance of ClassificationClassifier.
13 14 15 |
# File 'lib/mindee/v2/product/classification/classification_classifier.rb', line 13 def initialize(server_response) @document_type = server_response['document_type'] end |
Instance Attribute Details
#document_type ⇒ String (readonly)
Returns The document type, as identified on given classification values.
10 11 12 |
# File 'lib/mindee/v2/product/classification/classification_classifier.rb', line 10 def document_type @document_type end |
Instance Method Details
#to_s ⇒ String
Returns String representation.
18 19 20 |
# File 'lib/mindee/v2/product/classification/classification_classifier.rb', line 18 def to_s "Document Type: #{@document_type}" end |